---------------------------------------------------------------------
-- $Header: /ctcvs/hclroot/src/kor/korgrant.sql,v 1.2 2003/11/10 16:19:42 mevan Exp $ monitor.sql
--
-- ***************************************************************
-- Licensed Materials - Property of IBM
-- 5724-B96
--   
-- Copyright IBM Corp. 2005 All Rights Reserved
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp
-- ***************************************************************
--
-- Copyright (c) 1995 by Candle Corporation
-- NAME
--    korgrant.sql
-- FUNCTION
--   Grant access to all views used by Candle Command Center.
-- NOTES
--   This file must be run while logged-in as SYS.
--   Catalog.sql must have been run before this file is run.
--
--
-- MODIFIED
---------------------------------------------------------------------
--   Maintainence Log
--   @AL01 - 11/06/95 Date Created
--   @AL02 - 11/28/95 Removed the drop role candler because of serious bug
--                    with multiple oracle servers on same host, previous 
--		      users losing the permissions due to drop role command
--------------------------------------------------------------------------
-- Usage Instructions
-- Change directory to where this file is
--	cd <directory path  name of this file>
-- Bringup  sqlplus 
--	sqlplus
--	login : sys
--	password : <enter  password for user SYS>
-- Run this script
--	@korgrant.sql <enter user name as 1st argument>
-- Will output the log to the file korgrant.log in the current directory
--
-- For Oracle versions 7.1.4 and below use 'sys' as the database connect login
--
-- For Oracle versions 7.1.6 - grant failing on v$instance execute the following
-- command given below :
-- grant select any table		to &1;
--
-- For Oracle versions 7.2.X and above run this script
--------------------------------------------------------------------------

set echo on;
spool ./korgrant.log


-- Create and associate a tablespace with the user.
-- Initial space is 250MB.
create tablespace tivoliorts datafile 'tivoliorts.dbf' size 250m autoextend off;
alter user &1 default tablespace tivoliorts quota 250M on tivoliorts;
commit;

-- Serious bug @AL02 commented out
-- drop role candler;
-- create role &1;

------------------------------------------------
-- V$ grants first
------------------------------------------------
grant select on   V_$ARCHIVE_DEST   to &1;  
grant select on   V_$BACKUP         to &1;
grant select on   V_$BGPROCESS      to &1;
grant select on   V_$DATABASE       to &1;
grant select on   V_$DATAFILE       to &1;
grant select on   V_$INSTANCE       to &1;
grant select on   V_$LATCH          to &1;
grant select on   V_$LIBRARYCACHE   to &1;
grant select on   V_$LOCK           to &1;
grant select on   V_$OPEN_CURSOR    to &1;
grant select on   V_$OPTION         to &1;
grant select on   V_$PARAMETER      to &1;
grant select on   V_$PROCESS        to &1;
grant select on   V_$ROLLNAME       to &1;
grant select on   V_$ROLLSTAT       to &1;
grant select on   V_$ROWCACHE       to &1;
grant select on   V_$SESSION        to &1;
grant select on   V_$SESSION_WAIT   to &1;
grant select on   V_$SESS_IO        to &1;
grant select on   V_$SGA            to &1;
grant select on   V_$SGASTAT        to &1;
grant select on   V_$SQLTEXT        to &1;
grant select on   V_$SYSSTAT        to &1;
grant select on   V_$THREAD         to &1;
grant select on   V_$TRANSACTION    to &1;
grant select on   V_$VERSION        to &1;
grant select on   V_$LICENSE        to &1;
grant select on   V_$TEMP_EXTENT_MAP to &1;
grant select on   V_$WAITSTAT       to &1;
grant select on   V_$LOG            to &1;
grant select on   V_$HS_SESSION     to &1;
grant select on   V_$HS_AGENT       to &1;
grant select on   V_$QUEUE          to &1;
grant select on   V_$DISPATCHER     to &1;
grant select on   V_$SYSTEM_EVENT   to &1;
grant select on   V_$SHARED_SERVER  to &1;
grant select on   V_$ACCESS         to &1;
grant select on   V_$LOCK_ACTIVITY  to &1;

------------------------------------------------
-- DBA_ required tables
------------------------------------------------
grant select on   DUAL                 to &1;
grant select on   SYS.DBA_DATA_FILES   to &1;
grant select on   SYS.DBA_TEMP_FILES   to &1;
grant select on   SYS.DBA_EXTENTS      to &1;
grant select on   SYS.DBA_FREE_SPACE   to &1;
grant select on   SYS.DBA_SEGMENTS     to &1;
grant select on   SYS.DBA_TABLESPACES  to &1;
grant select on   SYS.OBJ$             to &1;
grant select on   SYS.DBA_VIEWS        to &1;
grant select on   SYS.DBA_SYNONYMS     to &1;
grant select on   SYS.ts$              to &1;
grant select on   SYS.fet$             to &1;
grant select on   SYS.uet$             to &1;
grant select on   SYS.file$            to &1;
grant select on   SYS.sys_dba_segs     to &1;
grant select on   SYS.DBA_QUEUE_SCHEDULES  to &1;
grant select on   SYS.GV_$AQ           to &1;
grant select on   SYS.DBA_TABLES       to &1;
grant select on   SYS.DBA_CLUSTERS     to &1;
grant select on   SYS.DBA_INDEXES      to &1;
grant select on   SYS.DBA_QUEUES       to &1;

------------------------------------------------
-- Grant create session to the user
------------------------------------------------
grant connect               to &1;
grant create session                    to &1;

------------------------------------------------
-- Grants needed to collect attributes that
-- use PL/SQL:
--   - Free Space Deficit   (Tablespace Segments)
--   - Table Chained Rows   (Table Summary) 
--   - Cluster Chained Rows (Cluster Summary)
--   - Index Percent Used   (Index Summary)
------------------------------------------------
grant create PROCEDURE 			to &1;
grant create TABLE 			to &1;
grant execute any PROCEDURE 		to &1;
grant unlimited tablespace 		to &1;

------------------------------------------------
-- Grants needed to collect attributes that
-- use analyze cluster|table or 
--     validate index:
--   - Table Chained Rows    (Table Summary) 
--   - Cluster Chained Rows  (Cluster Summary)
--   - Index Percent Deleted (Index Summary)
------------------------------------------------
GRANT analyze ANY                TO &1;


------------------------------------------------
-- Grant role candler to the user
------------------------------------------------
-- @AL02 grant candler              to &1;

spool off
set echo off;
------------------------------------------------
